@@ -3,7 +3,6 @@ import pytz
 from datetime import datetime, timedelta
 from typing import Dict, Union, List, Optional, Iterable
 from functools import partial
-from beartype import beartype
 
 from .methods import all_methods, Method, ISNA
 
@@ -23,7 +22,9 @@ __all__ = (
     "DefaultArgs",
     "Qibla",
     "Ism",
+    "Method",
 )
+# TODO: docs (errors)
 
 
 class Tune:
@@ -285,14 +286,12 @@ class CalendarDateArg:
             Whether `year` given is a hijri year or not.
     """
 
-    @beartype
     def __init__(
         self,
         year: int,
         month: Optional[int] = None,
         hijri: bool = False,
     ):
-        # TODO: check for year limits
         if month:
             if month not in range(1, 13):  # pragma: no cover
                 raise ValueError(
@@ -334,7 +333,6 @@ class TimingsDateArg:
 
     """
 
-    @beartype
     def __init__(self, date: Optional[Union[str, int, datetime]] = None):
         if date is None:
             date = datetime.utcnow()
@@ -382,6 +380,12 @@ class DefaultArgs:
             to Fajr).
             Default: Standard
 
+        timezonestring: Optional[:class:`str`]
+            A valid timezone name as specified on https://www.php.net/manual/en/timezones.php
+            Example: Europe/London. Calculated using the
+            co-ordinates provided by default. *This should be used only in
+            getters that uses co-ordinates or it will be ignored.*
+
         latitudeAdjustmentMethod: :class:`int`
             Method for adjusting times higher latitudes.
             For instance, if you are checking timings in the UK or Sweden.
@@ -399,6 +403,9 @@ class DefaultArgs:
         method: :class:`int`
             Method id.
 
+        method_params: Optional[dict[str, int or "null"]]
+            Method's parameters. ``None`` if method wasn't custom.
+
         tune: :class:`str`
             Tune Value.
 
@@ -406,30 +413,47 @@ class DefaultArgs:
 
         midnightMode: :class:`int`
 
+        timezonestring: :class:`str`
+
         latitudeAdjustmentMethod: :class:`int`
 
         adjustment: :class:`int`
+
+    *New in v0.2 method_params, timezonestring*
     """
 
-    # TODO: add timezone param
-
-    @beartype
     def __init__(
         self,
         method: Union[Method, int] = ISNA,
         tune: Optional[Tune] = None,
         school: int = Schools.SHAFI,
         midnightMode: int = MidnightModes.STANDARD,  # noqa
+        timezonestring: Optional[str] = None,
         latitudeAdjustmentMethod: int = LatitudeAdjustmentMethods.ANGLE_BASED,  # noqa
         adjustment: int = 0,
     ):
         # method
+        self.method_params = None
         if isinstance(method, Method):
+            if method.id == 99:
+                try:
+                    self.method_params = "{fajr},{maghrib},{isha}".format(
+                        **method.params
+                    )
+                except KeyError as e:
+                    raise KeyError(
+                        f"{e.args[0]!r} is required key in Method's params. "
+                        "https://aladhanpy.readthedocs.io/en/latest/"
+                        "api.html#aladhan.methods.Method for more info"
+                    )
             method = method.id
-
-        if method not in range(16):  # pragma: no cover
+        elif method == 99:
+            raise TypeError(
+                "Pass Method object instead if you want to use custom method"
+            )
+        if method not in range(16) and method != 99:  # pragma: no cover
             raise ValueError(
-                "Expected method in 0-15 range" " got {!r}".format(method)
+                "Expected method in 0-15 range or 99 got {!r}".format(method)
             )
         self.method = method
 
@@ -457,6 +481,11 @@ class DefaultArgs:
             )
         self.midnightMode = midnightMode
 
+        # timezone string
+        if timezonestring and timezonestring not in pytz.all_timezones_set:
+            raise ValueError("Invalid timezone.")
+        self.timezonestring = timezonestring
+
         # lat adj methods
         if latitudeAdjustmentMethod not in (1, 2, 3):  # pragma: no cover
             raise ValueError(
@@ -465,11 +494,12 @@ class DefaultArgs:
             )
         self.latitudeAdjustmentMethod = latitudeAdjustmentMethod
 
+        # adj
         self.adjustment = adjustment
 
     @property
     def as_dict(self):
-        return {
+        dct = {
             "method": self.method,
             "tune": self.tune,
             "school": self.school,
@@ -477,6 +507,11 @@ class DefaultArgs:
             "latitudeAdjustmentMethod": self.latitudeAdjustmentMethod,
             "adjustment": self.adjustment,
         }
+        if self.method == 99:
+            dct["methodSettings"] = self.method_params
+        if self.timezonestring:
+            dct["timezonestring"] = self.timezonestring
+        return dct
 
     def __hash__(self):  # pragma: no cover
         return hash(tuple(self.as_dict.values()))
@@ -501,8 +536,8 @@ class Meta:
         timezone:  :class:`pytz.UTC`
             Used timezone to calculate.
 
-        method: :class:`Method`
-            Calculation Method.
+        method: Optional[:class:`Method`]
+            Calculation Method. ``None`` if it was a custom method.
 
         latitudeAdjustmentMethod: :class:`str`
 
@@ -530,7 +565,7 @@ class Meta:
         self.longitude = longitude
         self.latitude = latitude
         self.timezone = pytz.timezone(timezone)
-        self.method = all_methods[method["id"]]
+        self.method = all_methods.get(method.get("id"))
         self.latitudeAdjustmentMethod = latitudeAdjustmentMethod
         self.midnightMode = midnightMode
         self.school = school
@@ -538,12 +573,18 @@ class Meta:
 
     @property
     def default_args(self):
-        """:class:`DefaultArgs`: returns a default args obj"""
-        return DefaultArgs(
-            self.method,
+        """:class:`DefaultArgs`: returns a default args obj
+
+        .. warning::
+            This will set method to ISNA if method was custom, and it will
+            always set adjustment to 0.
+        """
+        return DefaultArgs(  # TODO: testing
+            self.method or 2,
             self.offset,
             getattr(Schools, self.school.upper()),
             getattr(MidnightModes, self.midnightMode.upper()),
+            self.timezone.zone,
             getattr(
                 LatitudeAdjustmentMethods, self.latitudeAdjustmentMethod.upper()
             )
@@ -778,7 +819,7 @@ class Timings:
             "Isha": self.isha,
         }
 
-    async def next_prayer(self):
+    async def next_prayer(self) -> Prayer:
         """
         Get the next upcoming prayer.
         Don't use this for old dates.
