@@ -1,36 +1,11 @@
-import asyncio
 import aiohttp
-import platform
 
-from beartype import beartype
 from typing import Union, Dict, List, Optional
 
 from .methods import all_methods
 from .base_types import *
 from .endpoints import EndPoints
 
-from functools import wraps
-
-
-#  https://github.com/aio-libs/aiohttp/issues/4324#issuecomment-733884349
-if platform.system() == "Windows":  # pragma: no cover
-    from asyncio.proactor_events import _ProactorBasePipeTransport  # noqa
-
-    def silence_event_loop_closed(func):
-        @wraps(func)
-        def wrapper(self, *args, **kwargs):
-            try:
-                return func(self, *args, **kwargs)
-            except RuntimeError as e:
-                if str(e) != "Event loop is closed":
-                    raise
-
-        return wrapper
-
-    _ProactorBasePipeTransport.__del__ = silence_event_loop_closed(
-        _ProactorBasePipeTransport.__del__
-    )
-
 
 class AsyncClient:
     """Asynchronous al-adhan API client.
@@ -39,12 +14,25 @@ class AsyncClient:
         You need to initialize this class in a |coroutine_link|_.
     """
 
-    def __init__(self, loop: asyncio.AbstractEventLoop = None):
-        self._loop = loop or asyncio.get_event_loop()
+    def __init__(self, session: Optional[aiohttp.ClientSession] = None):
+        self.__session = session or aiohttp.ClientSession()
+
+    def __await__(self):
+        return self.__aenter__().__await__()
+
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc_val, exc_tb):
+        await self.close()
+        return exc_type is None
+
+    async def close(self):
+        """Closes the connection."""
+        await self.__session.close()
 
     async def _get_res(self, endpoint: str, params: dict) -> dict:
-        async with aiohttp.ClientSession(loop=self._loop) as session:
-            res = await session.get(endpoint, params=params)
+        async with self.__session.get(endpoint, params=params) as res:
             res = await res.json()
 
         if res["code"] != 200:  # something wrong
@@ -67,7 +55,6 @@ class AsyncClient:
             }
         return Data(**data, client=self).timings  # it is just a day timings
 
-    @beartype
     async def get_timings(
         self,
         longitude: Union[int, float],
@@ -110,7 +97,6 @@ class AsyncClient:
             EndPoints.TIMINGS + "/" + date.date, params
         )
 
-    @beartype
     async def get_timings_by_address(
         self,
         address: str,
@@ -148,7 +134,6 @@ class AsyncClient:
             EndPoints.TIMINGS_BY_ADDRESS + "/" + date.date, params
         )
 
-    @beartype
     async def get_timings_by_city(
         self,
         city: str,
@@ -200,7 +185,6 @@ class AsyncClient:
             EndPoints.TIMINGS_BY_CITY + "/" + date.date, params
         )
 
-    @beartype
     async def get_calendar(
         self,
         longitude: Union[int, float],
@@ -246,7 +230,6 @@ class AsyncClient:
             getattr(EndPoints, "HIJRI_" * date.hijri + "CALENDAR"), params
         )
 
-    @beartype
     async def get_calendar_by_address(
         self,
         address: str,
@@ -286,7 +269,6 @@ class AsyncClient:
             params,
         )
 
-    @beartype
     async def get_calendar_by_city(
         self,
         city: str,
@@ -354,7 +336,6 @@ class AsyncClient:
         """
         return all_methods
 
-    @beartype
     async def get_qibla(
         self, longitude: Union[int, float], latitude: Union[int, float]
     ):
@@ -377,7 +358,6 @@ class AsyncClient:
             )["data"]
         )
 
-    @beartype
     async def get_asma(self, *n: int):
         """|coro|
 
